==> totvs-log-web-foundation-0.0.9.tgz: package/src/lib/services/message/message.service.ts <==
import { Injectable, ComponentFactoryResolver, ApplicationRef, Injector, EmbeddedViewRef } from '@angular/core';
import { ShowMessageLinkActionType, ShowMessageOptions, AbstractShowMessage, I18nBaseService } from 'totvs-log-base-foundation';
import { ThfNotificationService } from '@totvs/thf-ui';
import { ThfNotification } from '@totvs/thf-ui';
import { ThfToasterOrientation } from '@totvs/thf-ui';
import { MessageComponent } from './message.component';
import { ShowMessageType } from 'totvs-log-base-foundation';

/**
 * Serviço de mensagens
 */
@Injectable()
export class MessageService extends AbstractShowMessage {

  /**
   * Atributo que recebe a instância da dialog criada
   */
  private messageDialogRef = undefined;

  /**
   * Método construtor da classe
   * @param thfNotification Parâmetro do serviço de notificação do THF
   * @param componentFactoryResolver Parâmetro do serviço que permite adicionar componentes dinamicamente
   * @param appRef Parâmetro que recebe a referência da aplicação Angular.
   * @param injector Parâmetro do serviço de injeção de dependência
   * @param i18n  Parâmetro do serviço de internacionalização
   */
  constructor(
    private thfNotification: ThfNotificationService,
    private componentFactoryResolver: ComponentFactoryResolver,
    private appRef: ApplicationRef,
    private injector: Injector,
    private i18n: I18nBaseService) {
    super();
  }
  /**
   * Método responsável por exibir uma mensagem, através de notificação ou dialog
   * @param showMessageOptions Parâmetro com as definições da mensagem
   */
  displayMessage(showMessageOptions: ShowMessageOptions): any {

    showMessageOptions = showMessageOptions;

    switch (showMessageOptions.messageType) {
      case ShowMessageType.NotificationError:
      case ShowMessageType.NotificationInformation:
      case ShowMessageType.NotificationSuccess:
      case ShowMessageType.NotificationWarning:
        this.showNotification(showMessageOptions);
        break;
      case ShowMessageType.DialogAlert:
      case ShowMessageType.DialogConfirmation:
        this.showDialog(showMessageOptions);
        break;
      default:
        throw new Error(`Tipo de mensagem inválido: ${showMessageOptions.messageType}`);
    }
  }



  /**
   * Método responsável por exibir uma notificação em tela
   * @param showMessageOptions Parâmetro com as definições da mensagem
   */
  private showNotification(showMessageOptions: ShowMessageOptions) {

    const thfNotification: ThfNotification = {
      message: showMessageOptions.messageText,
      orientation: ThfToasterOrientation.Top,
      action: this.processLinkAction(showMessageOptions),
      actionLabel: showMessageOptions.messageLinkLabel
    };

    switch (showMessageOptions.messageType) {
      case ShowMessageType.NotificationSuccess:
        this.thfNotification.success(thfNotification);
        break;
      case ShowMessageType.NotificationError:
        this.thfNotification.error(thfNotification);
        break;
      case ShowMessageType.NotificationInformation:
        this.thfNotification.information(thfNotification);
        break;
      case ShowMessageType.NotificationWarning:
        this.thfNotification.warning(thfNotification);
        break;
    }
  }

  /**
   * Método por exibir uma dialog em tela
   * @param showMessageOptions Parâmetro com as definições da mensagem
   */
  private showDialog(showMessageOptions: ShowMessageOptions) {

    this.createDialogComponent();
    this.setDialogOptions(showMessageOptions);
    this.messageDialogRef.instance.openDialog();
  }

  /**
   * Método responsável por abrir no navegador uma nova tab com o link recebido por parâmetro
   * @param link Link de uma página externa
   */
  private openLink(link: string) {
    link = link.indexOf('http://') === -1 ? `http://${link}` : link;
    window.open(link, '_blank');
  }

  /**
   * Método responsável por identificar se o link recebido é uma função ou página externa
   * @param showMessageOptions Parâmetro com as definições da mensagem
   */
  private processLinkAction(showMessageOptions: ShowMessageOptions) {

    let action;

    if (showMessageOptions.messageLinkActionType === ShowMessageLinkActionType.Method) {
      action = showMessageOptions.messageLinkAction;
    } else if (
      showMessageOptions.messageLinkActionType === ShowMessageLinkActionType.LinkNewTab &&
      showMessageOptions.messageLinkAction && showMessageOptions.messageLinkAction.trim() !== '') {
      action = () => {
        this.openLink(showMessageOptions.messageLinkAction);
      };
    }

    return action;
  }

  /**
   * Método responsável por criar o componente dialog
   */
  private createDialogComponent() {

    if ( this.messageDialogRef === undefined ) {

      this.messageDialogRef = this.componentFactoryResolver
        .resolveComponentFactory(MessageComponent)
        .create(this.injector);

      this.appRef.attachView(this.messageDialogRef.hostView);

      const domElem = (this.messageDialogRef.hostView as EmbeddedViewRef<any>)
        .rootNodes[0] as HTMLElement;

      document.body.appendChild(domElem);
    }
  }

  /**
   * Método responsável por setar as opções do componente dialog
   * @param showMessageOptions Parâmetro com as definições da mensagem
   */
  private setDialogOptions(showMessageOptions: ShowMessageOptions) {

    if (
      showMessageOptions.messageTitle !== undefined &&
      showMessageOptions.messageTitle.trim() !== '') {
      this.messageDialogRef.instance.messageTitle = showMessageOptions.messageTitle;
    } else if (showMessageOptions.messageType === ShowMessageType.DialogAlert) {
      this.messageDialogRef.instance.messageTitle = this.i18n.literals.warning;
    } else if (showMessageOptions.messageType === ShowMessageType.DialogConfirmation) {
      this.messageDialogRef.instance.messageTitle = this.i18n.literals.confirm;
    }

    this.messageDialogRef.instance.messageText = showMessageOptions.messageText;

    this.messageDialogRef.instance.messageDetails = showMessageOptions.messageDetails;

    this.messageDialogRef.instance.messageConfirmAction = {
      action: () => {
        if (showMessageOptions.messageConfirmAction) {
          showMessageOptions.messageConfirmAction();
        }
        this.messageDialogRef.instance.closeDialog();
      },
      label: showMessageOptions.messageConfirmLabel
    };

    this.messageDialogRef.instance.messageCancelAction = {
      action: () => {
        if (showMessageOptions.messageCancelAction) {
          showMessageOptions.messageCancelAction();
        }
        this.messageDialogRef.instance.closeDialog();
      },
      label: showMessageOptions.messageCancelLabel
    };

    this.messageDialogRef.instance.messageLinkActionType = showMessageOptions.messageLinkActionType;

    if (showMessageOptions.messageLinkActionType === ShowMessageLinkActionType.LinkNewTab) {
      const link = showMessageOptions.messageLinkAction;
      showMessageOptions.messageLinkAction = () => {
        this.openLink(link);
      };
    }
    this.messageDialogRef.instance.messageLinkAction = showMessageOptions.messageLinkAction;
    this.messageDialogRef.instance.messageLinkLabel = showMessageOptions.messageLinkLabel;
  }
}

==> totvs-log-web-foundation-1.0.0.tgz: package/src/lib/services/message/message.service.ts <==
import { Injectable, ComponentFactoryResolver, ApplicationRef, Injector, EmbeddedViewRef } from '@angular/core';
import { ShowMessageLinkActionType, ShowMessageOptions, AbstractShowMessage, I18nBaseService } from 'totvs-log-base-foundation';
import { PoNotificationService } from '@portinari/portinari-ui';
import { PoNotification } from '@portinari/portinari-ui';
import { PoToasterOrientation } from '@portinari/portinari-ui';
import { MessageComponent } from './message.component';
import { ShowMessageType } from 'totvs-log-base-foundation';

/**
 * Serviço de mensagens
 */
@Injectable()
export class MessageService extends AbstractShowMessage {

  /**
   * Atributo que recebe a instância da dialog criada
   */
  private messageDialogRef = undefined;

  /**
   * Método construtor da classe
   * @param poNotification Parâmetro do serviço de notificação do Po
   * @param componentFactoryResolver Parâmetro do serviço que permite adicionar componentes dinamicamente
   * @param appRef Parâmetro que recebe a referência da aplicação Angular.
   * @param injector Parâmetro do serviço de injeção de dependência
   * @param i18n  Parâmetro do serviço de internacionalização
   */
  constructor(
    private poNotification: PoNotificationService,
    private componentFactoryResolver: ComponentFactoryResolver,
    private appRef: ApplicationRef,
    private injector: Injector,
    private i18n: I18nBaseService) {
    super();
  }
  /**
   * Método responsável por exibir uma mensagem, através de notificação ou dialog
   * @param showMessageOptions Parâmetro com as definições da mensagem
   */
  displayMessage(showMessageOptions: ShowMessageOptions): any {

    showMessageOptions = showMessageOptions;

    switch (showMessageOptions.messageType) {
      case ShowMessageType.NotificationError:
      case ShowMessageType.NotificationInformation:
      case ShowMessageType.NotificationSuccess:
      case ShowMessageType.NotificationWarning:
        this.showNotification(showMessageOptions);
        break;
      case ShowMessageType.DialogAlert:
      case ShowMessageType.DialogConfirmation:
        this.showDialog(showMessageOptions);
        break;
      default:
        throw new Error(`Tipo de mensagem inválido: ${showMessageOptions.messageType}`);
    }
  }



  /**
   * Método responsável por exibir uma notificação em tela
   * @param showMessageOptions Parâmetro com as definições da mensagem
   */
  private showNotification(showMessageOptions: ShowMessageOptions) {

    const poNotification: PoNotification = {
      message: showMessageOptions.messageText,
      orientation: PoToasterOrientation.Bottom,
      action: this.processLinkAction(showMessageOptions),
      actionLabel: showMessageOptions.messageLinkLabel
    };

    switch (showMessageOptions.messageType) {
      case ShowMessageType.NotificationSuccess:
        this.poNotification.success(poNotification);
        break;
      case ShowMessageType.NotificationError:
        this.poNotification.error(poNotification);
        break;
      case ShowMessageType.NotificationInformation:
        this.poNotification.information(poNotification);
        break;
      case ShowMessageType.NotificationWarning:
        this.poNotification.warning(poNotification);
        break;
    }
  }

  /**
   * Método por exibir uma dialog em tela
   * @param showMessageOptions Parâmetro com as definições da mensagem
   */
  private showDialog(showMessageOptions: ShowMessageOptions) {

    this.createDialogComponent();
    this.setDialogOptions(showMessageOptions);
    this.messageDialogRef.instance.openDialog();
  }

  /**
   * Método responsável por abrir no navegador uma nova tab com o link recebido por parâmetro
   * @param link Link de uma página externa
   */
  private openLink(link: string) {
    link = link.indexOf('http://') === -1 ? `http://${link}` : link;
    window.open(link, '_blank');
  }

  /**
   * Método responsável por identificar se o link recebido é uma função ou página externa
   * @param showMessageOptions Parâmetro com as definições da mensagem
   */
  private processLinkAction(showMessageOptions: ShowMessageOptions) {

    let action;

    if (showMessageOptions.messageLinkActionType === ShowMessageLinkActionType.Method) {
      action = showMessageOptions.messageLinkAction;
    } else if (
      showMessageOptions.messageLinkActionType === ShowMessageLinkActionType.LinkNewTab &&
      showMessageOptions.messageLinkAction && showMessageOptions.messageLinkAction.trim() !== '') {
      action = () => {
        this.openLink(showMessageOptions.messageLinkAction);
      };
    }

    return action;
  }

  /**
   * Método responsável por criar o componente dialog
   */
  private createDialogComponent() {

    if ( this.messageDialogRef === undefined ) {

      this.messageDialogRef = this.componentFactoryResolver
        .resolveComponentFactory(MessageComponent)
        .create(this.injector);

      this.appRef.attachView(this.messageDialogRef.hostView);

      const domElem = (this.messageDialogRef.hostView as EmbeddedViewRef<any>)
        .rootNodes[0] as HTMLElement;

      document.body.appendChild(domElem);
    }
  }

  /**
   * Método responsável por setar as opções do componente dialog
   * @param showMessageOptions Parâmetro com as definições da mensagem
   */
  private setDialogOptions(showMessageOptions: ShowMessageOptions) {

    if (
      showMessageOptions.messageTitle !== undefined &&
      showMessageOptions.messageTitle.trim() !== '') {
      this.messageDialogRef.instance.messageTitle = showMessageOptions.messageTitle;
    } else if (showMessageOptions.messageType === ShowMessageType.DialogAlert) {
      this.messageDialogRef.instance.messageTitle = this.i18n.literals.warning;
    } else if (showMessageOptions.messageType === ShowMessageType.DialogConfirmation) {
      this.messageDialogRef.instance.messageTitle = this.i18n.literals.confirm;
    }

    this.messageDialogRef.instance.messageText = showMessageOptions.messageText;

    this.messageDialogRef.instance.messageDetails = showMessageOptions.messageDetails;

    this.messageDialogRef.instance.messageConfirmAction = {
      action: () => {
        if (showMessageOptions.messageConfirmAction) {
          showMessageOptions.messageConfirmAction();
        }
        this.messageDialogRef.instance.closeDialog();
      },
      label: showMessageOptions.messageConfirmLabel
    };

    this.messageDialogRef.instance.messageCancelAction = {
      action: () => {
        if (showMessageOptions.messageCancelAction) {
          showMessageOptions.messageCancelAction();
        }
        this.messageDialogRef.instance.closeDialog();
      },
      label: showMessageOptions.messageCancelLabel
    };

    this.messageDialogRef.instance.messageLinkActionType = showMessageOptions.messageLinkActionType;

    if (showMessageOptions.messageLinkActionType === ShowMessageLinkActionType.LinkNewTab) {
      const link = showMessageOptions.messageLinkAction;
      showMessageOptions.messageLinkAction = () => {
        this.openLink(link);
      };
    }
    this.messageDialogRef.instance.messageLinkAction = showMessageOptions.messageLinkAction;
    this.messageDialogRef.instance.messageLinkLabel = showMessageOptions.messageLinkLabel;
  }
}
